==> openssh-status-widget_1.6-5.tar.gz: openssh-status-widget-1.6/src/opt/maemo/usr/sbin/openssh-status.sh <==
#!/bin/sh

if [ "$1" = "start_sshd" ] ; then
        /etc/init.d/ssh start
fi

if [ "$1" = "stop_sshd" ] ; then
        /etc/init.d/ssh stop
fi

if [ "$1" = "kill_sshd" ] ; then
        killall sshd
fi

if [ "$1" = "disable_respawn" ] ; then
        sed -i 's/respawn/#respawn/g' /etc/event.d/sshd
fi

if [ "$1" = "disable_autostart" ] ; then
        sed -i 's/start on stopped rcS/#start on stopped rcS/g' /etc/event.d/sshd
fi

if [ "$1" = "enable_autostart" ] ; then
        sed -i 's/#start on stopped rcS/start on stopped rcS/g' /etc/event.d/sshd
fi

if [ "$1" = "disable_wifipmoff" ] ; then
        sed -i 's/#SSH_IP="disabled"/SSH_IP="disabled"/g' /usr/lib/openssh/session
        kill $(ps aux | grep /usr/lib/openssh/wifi-power-management | grep -v grep | awk '{print $1}')
        iwconfig wlan0 power on
fi

if [ "$1" = "enable_wifipmoff" ] ; then
        sed -i 's/#SSH_IP="disabled"/SSH_IP="disabled"/g' /usr/lib/openssh/session
        sed -i 's/SSH_IP="disabled"/#SSH_IP="disabled"/g' /usr/lib/openssh/session
        if [ $(ps aux | grep -v grep  | grep -c /usr/lib/openssh/wifi-power-management) = "0" ]; then
          /usr/lib/openssh/wifi-power-management &
        fi
fi

if [ "$1" = "disable_togglepm" ] ; then
        sed -i 's/iwconfig wlan0 power on #/#iwconfig wlan0 power on #/g' /usr/lib/openssh/wifi-power-management
        kill $(ps aux | grep /usr/lib/openssh/wifi-power-management | grep -v grep | awk '{print $1}')
        if [ $(ps aux | grep -v grep  | grep -c /usr/lib/openssh/wifi-power-management) = "0" ]; then
          /usr/lib/openssh/wifi-power-management &
        fi
fi

if [ "$1" = "enable_togglepm" ] ; then
        sed -i 's/#iwconfig wlan0 power on #/iwconfig wlan0 power on #/g' /usr/lib/openssh/wifi-power-management
        kill $(ps aux | grep /usr/lib/openssh/wifi-power-management | grep -v grep | awk '{print $1}')
        if [ $(ps aux | grep -v grep  | grep -c /usr/lib/openssh/wifi-power-management) = "0" ]; then
          /usr/lib/openssh/wifi-power-management &
        fi
fi

if [ "$1" = "set_pmoffsec" ] ; then
        sed -i 's/^.*#pmoff.*$/  sleep '$2' #pmoff/' /usr/lib/openssh/wifi-power-management
        kill $(ps aux | grep /usr/lib/openssh/wifi-power-management | grep -v grep | awk '{print $1}')
        if [ $(ps aux | grep -v grep  | grep -c /usr/lib/openssh/wifi-power-management) = "0" ]; then
          /usr/lib/openssh/wifi-power-management &
        fi
fi

if [ "$1" = "set_pmonsec" ] ; then
        sed -i 's/^.*#pmon.*$/  sleep '$2' #pmon/' /usr/lib/openssh/wifi-power-management
        kill $(ps aux | grep /usr/lib/openssh/wifi-power-management | grep -v grep | awk '{print $1}')
        if [ $(ps aux | grep -v grep  | grep -c /usr/lib/openssh/wifi-power-management) = "0" ]; then
          /usr/lib/openssh/wifi-power-management &
        fi
fi

if [ "$1" = "create_sshd" ] ; then
        echo "#start on stopped rcS" >> /etc/event.d/sshd
        echo "" >> /etc/event.d/sshd
        echo "console output" >> /etc/event.d/sshd
        echo "" >> /etc/event.d/sshd
        echo "#respawn" >> /etc/event.d/sshd
        echo "" >> /etc/event.d/sshd
        echo "pre-start script" >> /etc/event.d/sshd
        echo "    if [ ! -d /var/run/sshd ] ; then" >> /etc/event.d/sshd
        echo "        mkdir /var/run/sshd" >> /etc/event.d/sshd
        echo "        chmod 755 /var/run/sshd" >> /etc/event.d/sshd
        echo "    fi" >> /etc/event.d/sshd
        echo "end script" >> /etc/event.d/sshd
        echo "" >> /etc/event.d/sshd
        echo "exec /usr/sbin/sshd" >> /etc/event.d/sshd
fi

if [ "$1" = "insert_start" ] ; then
        sed -i '1i#start on stopped rcS' /etc/event.d/sshd
fi

if [ "$1" = "no_force" ] ; then
        sed -i 's/ForceCommand/#ForceCommand/g' /etc/ssh/sshd_config
fi

if [ "$1" = "insert_wifipm" ] ; then
        sed -i '/# OpenSSH Status Widget entry for controling wifi power management/d' /etc/ssh/sshd_config
        sed -i '/# Do not edit, instead edit session to force a command/d' /etc/ssh/sshd_config
        sed -i '/ForceCommand \/usr\/lib\/openssh\/session/d' /etc/ssh/sshd_config
        echo "# OpenSSH Status Widget entry for controling wifi power management" >> /etc/ssh/sshd_config
        echo "# Do not edit, instead edit session to force a command" >> /etc/ssh/sshd_config
        echo "ForceCommand /usr/lib/openssh/session" >> /etc/ssh/sshd_config
fi

==> openssh-status-widget_2.0-0.tar.gz: openssh-status-widget-2.0/src/opt/maemo/usr/sbin/openssh-status.sh <==
#!/bin/sh

if [ "$1" = "start_sshd" ] ; then
        /etc/init.d/ssh start
fi

if [ "$1" = "stop_sshd" ] ; then
        /etc/init.d/ssh stop
fi

if [ "$1" = "kill_sshd" ] ; then
        killall sshd
fi

if [ "$1" = "disable_respawn" ] ; then
        sed -i 's/respawn/#respawn/g' /etc/event.d/sshd
fi

if [ "$1" = "disable_autostart" ] ; then
        sed -i 's/start on stopped rcS/#start on stopped rcS/g' /etc/event.d/sshd
fi

if [ "$1" = "enable_autostart" ] ; then
        sed -i 's/#start on stopped rcS/start on stopped rcS/g' /etc/event.d/sshd
fi

if [ "$1" = "disable_wifipmoff" ] ; then
        sed -i 's/#SSH_IP="disabled"/SSH_IP="disabled"/g' /usr/lib/openssh/session
        if [ $(ps aux | grep -v grep  | grep -c /usr/lib/openssh/wifi-power-management\ once) = "0" ]; then
          kill $(ps aux | grep /usr/lib/openssh/wifi-power-management | grep -v grep | awk '{print $1}')
          iwconfig wlan0 power on
        fi
fi

if [ "$1" = "enable_wifipmoff" ] ; then
        sed -i 's/#SSH_IP="disabled"/SSH_IP="disabled"/g' /usr/lib/openssh/session
        sed -i 's/SSH_IP="disabled"/#SSH_IP="disabled"/g' /usr/lib/openssh/session
        if [ $(ps aux | grep -v grep  | grep -c /usr/lib/openssh/wifi-power-management) = "0" ]; then
          /usr/lib/openssh/wifi-power-management &
        fi
fi

if [ "$1" = "disconnect" ] ; then
        if [ $(ps aux | grep -v grep  | grep -c /usr/lib/openssh/wifi-power-management\ once) = "0" ]; then
          kill $(ps aux | grep /usr/lib/openssh/wifi-power-management | grep -v grep | awk '{print $1}')
          iwconfig wlan0 power on
        fi
fi

if [ "$1" = "disable_togglepm" ] ; then
        sed -i 's/iwconfig wlan0 power on #/#iwconfig wlan0 power on #/g' /usr/lib/openssh/wifi-power-management
        if [ $(ps aux | grep -v grep  | grep -c /usr/lib/openssh/wifi-power-management\ once) = "0" ]; then
          kill $(ps aux | grep /usr/lib/openssh/wifi-power-management | grep -v grep | awk '{print $1}')
          if [ $(ps aux | grep -v grep  | grep -c /usr/lib/openssh/wifi-power-management) = "0" ]; then
            /usr/lib/openssh/wifi-power-management &
          fi
        fi
fi

if [ "$1" = "enable_togglepm" ] ; then
        sed -i 's/#iwconfig wlan0 power on #/iwconfig wlan0 power on #/g' /usr/lib/openssh/wifi-power-management
        if [ $(ps aux | grep -v grep  | grep -c /usr/lib/openssh/wifi-power-management\ once) = "0" ]; then
          kill $(ps aux | grep /usr/lib/openssh/wifi-power-management | grep -v grep | awk '{print $1}')
          if [ $(ps aux | grep -v grep  | grep -c /usr/lib/openssh/wifi-power-management) = "0" ]; then
            /usr/lib/openssh/wifi-power-management &
          fi
        fi
fi

if [ "$1" = "wifipmoff_once" ] ; then
        kill $(ps aux | grep /usr/lib/openssh/wifi-power-management | grep -v grep | awk '{print $1}')
        sleep 0.2
        kill $(ps aux | grep /usr/lib/openssh/wifi-power-management | grep -v grep | awk '{print $1}')
        if [ $(ps aux | grep -v grep  | grep -c /usr/lib/openssh/wifi-power-management) = "0" ]; then
          /usr/lib/openssh/wifi-power-management once &
        fi
fi

if [ "$1" = "set_pmoffsec" ] ; then
        sed -i 's/^.*#pmoff.*$/  sleep '$2' #pmoff/' /usr/lib/openssh/wifi-power-management
        if [ $(ps aux | grep -v grep  | grep -c /usr/lib/openssh/wifi-power-management\ once) = "0" ]; then
          kill $(ps aux | grep /usr/lib/openssh/wifi-power-management | grep -v grep | awk '{print $1}')
          if [ $(ps aux | grep -v grep  | grep -c /usr/lib/openssh/wifi-power-management) = "0" ]; then
            /usr/lib/openssh/wifi-power-management &
          fi
        fi
fi

if [ "$1" = "set_pmonsec" ] ; then
        sed -i 's/^.*#pmon.*$/  sleep '$2' #pmon/' /usr/lib/openssh/wifi-power-management
        if [ $(ps aux | grep -v grep  | grep -c /usr/lib/openssh/wifi-power-management\ once) = "0" ]; then
          kill $(ps aux | grep /usr/lib/openssh/wifi-power-management | grep -v grep | awk '{print $1}')
          if [ $(ps aux | grep -v grep  | grep -c /usr/lib/openssh/wifi-power-management) = "0" ]; then
            /usr/lib/openssh/wifi-power-management &
          fi
        fi
fi

if [ "$1" = "create_sshd" ] ; then
        echo "#start on stopped rcS" >> /etc/event.d/sshd
        echo "" >> /etc/event.d/sshd
        echo "console output" >> /etc/event.d/sshd
        echo "" >> /etc/event.d/sshd
        echo "#respawn" >> /etc/event.d/sshd
        echo "" >> /etc/event.d/sshd
        echo "pre-start script" >> /etc/event.d/sshd
        echo "    if [ ! -d /var/run/sshd ] ; then" >> /etc/event.d/sshd
        echo "        mkdir /var/run/sshd" >> /etc/event.d/sshd
        echo "        chmod 755 /var/run/sshd" >> /etc/event.d/sshd
        echo "    fi" >> /etc/event.d/sshd
        echo "end script" >> /etc/event.d/sshd
        echo "" >> /etc/event.d/sshd
        echo "exec /usr/sbin/sshd" >> /etc/event.d/sshd
fi

if [ "$1" = "insert_start" ] ; then
        sed -i '1i#start on stopped rcS' /etc/event.d/sshd
fi

if [ "$1" = "no_force" ] ; then
        sed -i 's/ForceCommand/#ForceCommand/g' /etc/ssh/sshd_config
fi

if [ "$1" = "insert_wifipm" ] ; then
        sed -i '/# OpenSSH Status Widget entry for controling wifi power management/d' /etc/ssh/sshd_config
        sed -i '/# Do not edit, instead edit session to force a command/d' /etc/ssh/sshd_config
        sed -i '/ForceCommand \/usr\/lib\/openssh\/session/d' /etc/ssh/sshd_config
        echo "# OpenSSH Status Widget entry for controling wifi power management" >> /etc/ssh/sshd_config
        echo "# Do not edit, instead edit session to force a command" >> /etc/ssh/sshd_config
        echo "ForceCommand /usr/lib/openssh/session" >> /etc/ssh/sshd_config
fi
